#!/usr/bin/python3
import sqlite3

conn = sqlite3.connect('rh.db')
conn.row_factory = sqlite3.Row

cur = conn.cursor()


# iterating over query results
print("Printing names of a specified job title")
title = 'Chef Entrepot' 
#title = 'Secretaire'
for emp in cur.execute("SELECT * FROM EMPLOYE WHERE TITRE=?",[title]):
    print(emp['Prenom'],emp['Nom'])
print("DONE")
print("")

# nested loops iterating over query results
# the bad way
print("Print 3 employee names and the names of their subordinates")
print("Printing 3 names of employees")
for emp in cur.execute('SELECT * FROM EMPLOYE LIMIT 3'):
    print(emp['Prenom'],emp['Nom'])
    for sub in cur.execute("""SELECT EMPLOYE.* 
                                 FROM EMPLOYE 
                                 JOIN SUPERIEUR ON EMPLOYE.ID = SUPERIEUR.ID_EMPLOYE 
                                WHERE SUPERIEUR.ID_SUPERIEUR = ?""",[emp['ID']]):
        print("   ",sub['Prenom'],sub['Nom'])
print("DONE")
print("")



# nested loops iterating over query results
# the right way (two cursors)
sub_cur = conn.cursor()
print("Print 3 employee names and the names of their subordinates")
print("Printing 3 names of employees")
for emp in cur.execute('SELECT * FROM EMPLOYE LIMIT 3'):
    print(emp['Prenom'],emp['Nom'])
    for sub in sub_cur.execute("""SELECT EMPLOYE.* 
                                    FROM EMPLOYE 
                                    JOIN SUPERIEUR ON EMPLOYE.ID = SUPERIEUR.ID_EMPLOYE 
                                   WHERE SUPERIEUR.ID_SUPERIEUR = ?""",[emp['ID']]):
        print("   ",sub['Prenom'],sub['Nom'])
print("DONE")
print("")


# nested loops iterating over query results
# the geeky way (one cursor, join query)

cur.execute("""SELECT B.ID AS "B_ID", B.Prenom AS "B_Prenom", B.Nom AS "B_Nom", E.Prenom AS "E_Prenom", E.Nom AS "E_Nom"
               FROM EMPLOYE B 
               LEFT OUTER JOIN SUPERIEUR S ON B.ID = S.ID_SUPERIEUR
               LEFT OUTER JOIN EMPLOYE E ON S.ID_EMPLOYE = E.ID
               ORDER BY B.ID""")

current_boss_id = None
row = cur.fetchone()
while row:
    if current_boss_id != row['B_ID']:
        print(row['B_Prenom'],row['B_Nom'])
        current_boss_id = row['B_ID']
    if row['E_Prenom']:
        print("   ", row['E_Prenom'],row['E_Nom'])
    row = cur.fetchone()
    
